Package: rdomains
Title: Get the Category of Content Hosted by a Domain
Version: 0.5.0
Authors@R: person("Gaurav", "Sood", email = "gsood07@gmail.com", role = c("aut", "cre"))
Description: Get the category of content hosted by a domain. Use Shallalist (service discontinued),
    'VirusTotal' (which provides access to lots of services) <https://www.virustotal.com/>,
    'DMOZ' <https://archive.org/details/dmoz-rdf-20150327>, University Domain list
    <https://github.com/Hipo/university-domains-list>, 'OpenAI' 'GPT' models, 'Anthropic' 'Claude' models,
    or validated machine learning classifiers based on 'Shallalist' data to learn about the kind
    of content hosted by a domain.
Depends: R (>= 4.1.0)
Imports: Matrix, urltools, glmnet, stats, methods, XML, httr, httr2,
        xml2, curl, virustotal, jsonlite, R.utils, dplyr (>= 1.1.0),
        purrr (>= 1.0.0), tibble (>= 3.2.0), stringr (>= 1.5.0), rlang
        (>= 1.1.0), cli (>= 3.6.0), checkmate (>= 2.3.0), glue (>=
        1.6.0), readr (>= 2.1.0)
Suggests: testthat, rmarkdown, knitr (>= 1.11), withr
VignetteBuilder: knitr
License: MIT + file LICENSE
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-08-02 08:22:57 UTC; soodoku
Author: Gaurav Sood [aut, cre]
Maintainer: Gaurav Sood <gsood07@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-02 09:00:02 UTC
