# Generated by roxygen2: do not edit by hand

export(adult_ml1_cat)
export(claude_cat)
export(dmoz_cat)
export(get_dmoz_data)
export(get_shalla_data)
export(get_stevenblack_data)
export(glm_shalla)
export(not_news)
export(openai_cat)
export(shalla_cat)
export(stevenblack_cat)
export(uni_cat)
export(virustotal_cat)
importFrom(Matrix,Matrix)
importFrom(Matrix,spMatrix)
importFrom(Matrix,sparseVector)
importFrom(R.utils,gunzip)
importFrom(XML,readHTMLTable)
importFrom(checkmate,assert_character)
importFrom(checkmate,assert_file_exists)
importFrom(checkmate,assert_logical)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(cli,cli_warn)
importFrom(curl,curl_download)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,coalesce)
importFrom(dplyr,mutate)
importFrom(glmnet,predict.glmnet)
importFrom(glue,glue)
importFrom(httr,GET)
importFrom(httr,POST)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(httr,oauth_app)
importFrom(httr,oauth_signature)
importFrom(httr,status_code)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(methods,as)
importFrom(purrr,map_chr)
importFrom(purrr,map_df)
importFrom(readr,read_csv)
importFrom(rlang,.data)
importFrom(rlang,abort)
importFrom(rlang,inform)
importFrom(rlang,warn)
importFrom(stats,predict)
importFrom(stats,setNames)
importFrom(stringr,str_detect)
importFrom(stringr,str_remove)
importFrom(stringr,str_trim)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(urltools,suffix_extract)
importFrom(utils,URLencode)
importFrom(utils,read.csv)
importFrom(utils,read.table)
importFrom(utils,untar)
importFrom(utils,unzip)
importFrom(utils,write.csv)
importFrom(virustotal,domain_report)
importFrom(virustotal,set_key)
importFrom(xml2,as_list)
importFrom(xml2,read_xml)
