#' ML Model
#'
#'
#' @docType data
#' @keywords keywords model
#' @name glm_shalla
#' @source ML model based on shallalist using keywords and domain suffixes,
#'
#' @format A list
#' @author Gaurav Sood
#' @export
"glm_shalla"
